@@ -1,5 +1,5 @@
 if 'backUpVals' not in globals():
-    globals()['backUpVals'] = []
+    globals()['backUpVals'] = {}
 if 'restoreMethods' not in globals():
     globals()['restoreMethods'] = {}
 
