@@ -40,7 +40,7 @@ def writeChannels(chanInfo, bak=backUpVals):
             else:
                 curVals['channels'][ch][key] = chanInfo['channels'][ch][key]
     if all([set(curVals['channels']) != set(ele['value']['channels'])
-            for ele in bak.items() if ele['type'] == 'group']):
+            for ele in bak.values() if ele['type'] == 'group']):
         name = 'group_of|' + '|'.join(list(curVals['channels'].keys()))
         bak[name] = {'type': 'group', 'value': curVals, 'sno': len(bak)}
 
