@@ -16,7 +16,7 @@ def writeMatrix(basename, inpMat, firstRow=1, firstCol=1, suffix=None,
     if basename not in bak:
         bak[basename] = {'type': 'matrix', 'name': basename, 'suffix': suffix,
                          'value': curMat, 'firstRow': firstRow,
-                         'firstCol': firstCol,'tramp': tramp, 'sno': len(bak)}
+                         'firstCol': firstCol, 'tramp': tramp, 'sno': len(bak)}
     # Special case, changing filter gains, can use TRAMP
     rampYourself = True
     if suffix == 'GAIN':
@@ -65,7 +65,7 @@ def writeMatrix(basename, inpMat, firstRow=1, firstCol=1, suffix=None,
 def restoreMatrix(bakVal):
     writeMatrix(basename=bakVal['name'], suffix=bakVal['suffix'],
                 inpMat=bakVal['value'], firstCol=bakVal['firstCol'],
-                firstRow=bakVal['firstRow'], tramp=10, bak=[])
+                firstRow=bakVal['firstRow'], tramp=10, bak={})
 
 
 restoreMethods['matrix'] = restoreMatrix
